<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy applicazione</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo di proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Indirizzo IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opzionale</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Seleziona &quot;Usa un proxy&quot; nel menu contestuale del Launcher dopo averlo configurato</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Indirizzo IP non valido</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Porta non valida</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Disconnetti</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connessione in corso</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Disconnetti</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Sicuro di voler eliminare questa configurazione?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Connessione cablata %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Connessione WiFi %1 </translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Connessione PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nuova VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipo VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Esporta</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy applicazione</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot personale</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Dettagli di rete</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy di sistema</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Connessione cablata</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Connessione WiFi</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modalità aereo</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Scheda di rete</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Aggiungi connessione ad internet</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Scheda di rete</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connetti ad una rete nascosta</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Crea connessione PPPoE</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Stato VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Crea VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importa VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo di proxy</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configurazione URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Indirizzo IP</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Crea un Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaccia</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Primario</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefisso</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocità</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modalità aereo</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>L&apos;abilitazione della modalità aereo disattiva la rete wireless, l&apos;hotspot personale e il Bluetooth</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Indirizzo DNS non valido</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Non collegato</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Indirizzo MAC</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Indirizzo MAC Clone</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Modifica MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Questo nome esiste già</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Connessione automatica</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Aggiungi configurazione </translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Crea un Hotspot</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>Indirizzo IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesto</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Indirizzo IP Duplicato</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Indirizzo IP non valido</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Netmask non valida</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>E&apos; permesso un solo un gateway</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway non valido</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesto</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Indirizzo IP Duplicato</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Indirizzo IP non valido</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>E&apos; permesso un solo un gateway</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway non valido</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefisso</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Indirizzo IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Applicazione sulle sole risorse corrispondenti</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metodo</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefisso</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Indirizzo IP non valido</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Netmask non valida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway non valido</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metodo</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Dettagli di rete</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Proxy di sistema</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Proxy applicazione</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modalità aereo</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Dettagli di rete</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabilitato</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Configura dal Network Manager</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Hotspot personale</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servizio</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Autenticazione EAP Rifiutata</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Autenticazione PAP Rifiutata</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Autenticazione CHAP Rifiutata</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Autenticazione MSCHAP Rifiutata</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Autenticazione MSCHAPv2 Rifiutata</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Compressione Dati BSD disabilitata</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Compressione dati deflate disabilitata</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Compressione TCP Header non presente</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Protocol Field Compression disabilitato</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Address/Control Compression disabilitato</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Invia pacchetti PPP Echo</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usa MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>MPPE 128 Bit</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE Stateful</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Crea connessione PPPoE</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy di sistema</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo di proxy</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opzionale</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignora la configurazione proxy per gli hosts e domini sopra-indicati</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Configurazione URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Sicurezza</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunneled TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Protected EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Salva la password solo per me</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Salva la password per tutti gli utenti</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Chiedi sempre</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabilitato</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonimo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticato</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Entrambi</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versione 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versione 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>Autenticazione EAP</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identità</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opzioni Password</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chiave privata</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>User Cert</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID Anonimo</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Fornitura</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>File PAC</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticazione Inner</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versione PEAP</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Password privata</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Password non valida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personale</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicurezza</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chiave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Richesta sicurezza</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Password non valida</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personale</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Chiave condivisa</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Apri la cartella System</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicurezza</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticazione</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Chiave</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avanzato</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Modifica porta gateway</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Porta gateway</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Modifica intervallo di rinegoziazione</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervallo di rinegoziazione</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Usa compressione dati LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Usa connessione TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Usa un dispositivo TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Modifica Tunnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Modifica UDP Fragment Size</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP Fragment Size</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Limita Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Rendi casuale il Remote Hosts</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avanzato</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (default)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Sicura (default)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Scarsa</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T quando disponibile (default)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Always</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Disabilitato</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2 (default)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (default)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Dominio</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Marca</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Crittografia</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Traversal Mode</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Gruppo IKE DH</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Porta locale</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Disabilita il rilevamento Dead Peer</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Abilita IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome gruppo</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID Gruppo</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chiave pre-condivisa</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmi Phase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmi Phase2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway non valido</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permetti Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Script</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>User Cert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chiave privata</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Usa FSID per la Key Passphrase</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway non valido</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificato (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificazione con password (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Chiave statica</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvato</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Chiedi</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non richiesto</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo di autenticazione</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>User Cert</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chiave privata</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opzioni Password</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Password privata</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Customize Key Direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Direction</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP Remoto</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP Locale</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tutte disponibili (default)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (meno sicura)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (più sicura)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Autenticazione EAP Rifiutata</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Autenticazione PAP Rifiutata</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Autenticazione CHAP Rifiutata</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Autenticazione MSCHAP Rifiutata</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Autenticazione MSCHAPv2 Rifiutata</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Compressione Dati BSD disabilitata</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Compressione dati deflate disabilitata</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Compressione TCP Header non presente</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Protocol Field Compression disabilitato</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Address/Control Compression disabilitato</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Invia pacchetti PPP Echo</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usa MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sicurezza</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE Stateful</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Stato VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Crea VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importa VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Errori di import</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Errore file</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non richiesto</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo di proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Server</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Riprova nuovamente se fallisce</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>File CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ignora avvisi sul certificato</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Usa estensione TLS Hostname</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Sicurezza VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cifra</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>Autenticazione HMAC</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway non valido</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvato</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Chiedi</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non richiesto</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opzioni Password</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Domain</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>Proxy VPN</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP Server</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway non valido</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Chiave privata</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Smart Card</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Chiave pre-condivisa</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Cert</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo di autenticazione</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>User Cert</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Richiedi un indirizzo IP interno</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Utilizza incapsulamento UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Usa compressione IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Abilita cipher proposals personalizzato</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticazione VPN TLS</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Subject Match</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipo di certificazione remota</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>File chiave</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Customize Key Direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Direction</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Gateway non valido</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Salvato</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Chiedi</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Non richiesto</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente </translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opzioni Password</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nome gruppo</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Password gruppo</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Usa autenticazione ibrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>File CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Collega prima il cavo di rete</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Scheda di rete</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Aggiungi connessione ad internet</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Seleziona configurazione</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Scheda di rete</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Spegni l&apos;hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Disattiva prima l&apos;hotspot se desideri connetterti ad una rete WiFi</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connetti ad una rete nascosta</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Non collegato</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Richiesta</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Indirizzo MAC</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Modifica MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocollo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo sicurezza</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canale</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefisso</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo disattivato</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connesso senza accesso ad internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cavo di rete scollegato</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connessione in corso</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificazione in corso</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Ottenimento indirizzo IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connesso</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Disconnesso</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Connessione fallita</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Ottenimento indirizzo</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Connessione cablata</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Connessione cablata %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Connessione WiFi</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rete wireless %1</translation>
    </message>
</context>
</TS>